--
-- xmonad example config file.
--
-- A template showing all available configuration hooks,
-- and how to override the defaults in your own xmonad.hs conf file.
--
-- Normally, you'd only override those defaults you care about.
--
 
import XMonad
import System.Exit
import XMonad.Layout.Reflect 
import XMonad.Layout.Grid
import XMonad.Layout.Master
import XMonad.Layout.Circle
import XMonad.Layout.PerWorkspace
--import XMonad.Actions.SimpleDate
import XMonad.Util.Cursor
import XMonad.Hooks.DynamicLog
import XMonad.Hooks.ManageDocks
import XMonad.Util.Run(spawnPipe)
import System.IO
 
import qualified XMonad.StackSet as W
import qualified Data.Map        as M
 
-- The preferred terminal program, which is used in a binding below and by
-- certain contrib modules.
--
--myTerminal      = "xterm zsh"

myTerminal      = "xterm"
 
-- Width of the window border in pixels.
--
myBorderWidth   = 1
 
-- modMask lets you specify which modkey you want to use. The default
-- is mod1Mask ("left alt").  You may also consider using mod3Mask
-- ("right alt"), which does not conflict with emacs keybindings. The
-- "windows key" is usually mod4Mask.
--
myModMask       = mod4Mask
 
-- The mask for the numlock key. Numlock status is "masked" from the
-- current modifier status, so the keybindings will work with numlock on or
-- off. You may need to change this on some systems.
--
-- You can find the numlock modifier by running "xmodmap" and looking for a
-- modifier with Num_Lock bound to it:
--
-- > $ xmodmap | grep Num
-- > mod2        Num_Lock (0x4d)
--
-- Set numlockMask = 0 if you don't have a numlock key, or want to treat
-- numlock status separately.
--
myNumlockMask   = mod2Mask
 
-- The default number of workspaces (virtual screens) and their names.
-- By default we use numeric strings, but any string may be used as a
-- workspace name. The number of workspaces is determined by the length
-- of this list.
--
-- A tagging example:
--
-- > workspaces = ["web", "irc", "code" ] ++ map show [4..9]
--
myWorkspaces    = ["web","mail","icq","4","5","6","7","m-n-t","skype"]
 
-- Border colors for unfocused and focused windows, respectively.
--
myNormalBorderColor  = "#dddddd"
myFocusedBorderColor = "#ff0000"
 
------------------------------------------------------------------------
-- Key bindings. Add, modify or remove key bindings here.
--
myKeys conf@(XConfig {XMonad.modMask = modm}) = M.fromList $
 
    -- launch a terminal
    [ ((modm .|. shiftMask, xK_Return), spawn $ XMonad.terminal conf)
 
    -- launch dmenu
    , ((modm,               xK_p     ), spawn "exe=`dmenu_path | dmenu` && eval \"exec $exe\"")
   
    -- launch date/time
    --, ((modm,               xK_d     ), date)
 
    -- make screenshot 
    , ((modm,               xK_Print     ), spawn "import -window root ~/ekran.png")

    -- launch gmrun
    , ((modm .|. shiftMask, xK_p     ), spawn "gmrun")
    
   -- launch firefox
    , ((modm .|. shiftMask, xK_f     ), spawn "firefox")
 
   -- launch google-chrome
    , ((modm .|. shiftMask, xK_g     ), spawn "google-chrome")
 
   -- launch thunderbird
    , ((modm .|. shiftMask, xK_b     ), spawn "thunderbird")
 
   -- launch skype
    , ((modm .|. shiftMask, xK_z     ), spawn "skype")
 
   -- launch pidjin
    --, ((modm .|. shiftMask, xK_a     ), spawn "pidgin")
    , ((modm .|. shiftMask, xK_a     ), spawn "empathy")

   -- launch google-chrome
    , ((modm .|. shiftMask, xK_s     ), spawn "sh ~/.xmonad/xmstartup.sh")

   -- mount flash 
    , ((modm .|. shiftMask, xK_y     ), spawn "mount /dev/sdb1")
 
   -- umount flash
    , ((modm .|. shiftMask, xK_u     ), spawn "umount /media/flash")

  -- volume+
    , ((modm .|. shiftMask, xK_Up    ), spawn "amixer -q set Master 1+")

  --volume-
    , ((modm .|. shiftMask, xK_Down    ), spawn "amixer -q set Master 1-")

    -- close focused window 
    , ((modm .|. shiftMask, xK_c     ), kill)
 
     -- Rotate through the available layout algorithms
    , ((modm,               xK_space ), sendMessage NextLayout)
 
    --  Reset the layouts on the current workspace to default
    , ((modm .|. shiftMask, xK_space ), setLayout $ XMonad.layoutHook conf)
 
    -- Resize viewed windows to the correct size
    , ((modm,               xK_n     ), refresh)
 
    -- Move focus to the next window
    , ((modm,               xK_Tab   ), windows W.focusDown)
 
    -- Move focus to the next window
    , ((modm,               xK_j     ), windows W.focusDown)
 
    -- Move focus to the previous window
    , ((modm,               xK_k     ), windows W.focusUp  )
 
    -- Move focus to the master window
    , ((modm,               xK_m     ), windows W.focusMaster  )
 
    -- Swap the focused window and the master window
    , ((modm,               xK_Return), windows W.swapMaster)
 
    -- Swap the focused window with the next window
    , ((modm .|. shiftMask, xK_j     ), windows W.swapDown  )
 
    -- Swap the focused window with the previous window
    , ((modm .|. shiftMask, xK_k     ), windows W.swapUp    )
 
    -- Shrink the master area
    , ((modm,               xK_h     ), sendMessage Shrink)
 
    -- Expand the master area
    , ((modm,               xK_l     ), sendMessage Expand)
 
    -- Push window back into tiling
    , ((modm,               xK_t     ), withFocused $ windows . W.sink)
 
    -- Increment the number of windows in the master area
    , ((modm              , xK_comma ), sendMessage (IncMasterN 1))
 
    -- Deincrement the number of windows in the master area
    , ((modm              , xK_period), sendMessage (IncMasterN (-1)))

    -- xmobar On/Off
    , ((modm              , xK_b), sendMessage ToggleStruts)
 
    -- toggle the status bar gap (used with avoidStruts from Hooks.ManageDocks)
    -- , ((modm , xK_b ), sendMessage ToggleStruts)
 
    -- Quit xmonad
    , ((modm .|. shiftMask, xK_q     ), io (exitWith ExitSuccess))
 
    -- Restart xmonad
    , ((modm              , xK_q     ), restart "xmonad" True)

    ]
    ++
 
    --
    -- mod-[1..9], Switch to workspace N
    -- mod-shift-[1..9], Move client to workspace N
    --
    [((m .|. modm, k), windows $ f i)
        | (i, k) <- zip (XMonad.workspaces conf) [xK_1 .. xK_9]
        , (f, m) <- [(W.greedyView, 0), (W.shift, shiftMask)]]
    ++
 
    --
    -- mod-{w,e,r}, Switch to physical/Xinerama screens 1, 2, or 3
    -- mod-shift-{w,e,r}, Move client to screen 1, 2, or 3
    --
    [((m .|. modm, key), screenWorkspace sc >>= flip whenJust (windows . f))
        | (key, sc) <- zip [xK_w, xK_e, xK_r] [0..]
        , (f, m) <- [(W.view, 0), (W.shift, shiftMask)]]
 
 
------------------------------------------------------------------------
-- Mouse bindings: default actions bound to mouse events
--
myMouseBindings (XConfig {XMonad.modMask = modMask}) = M.fromList $
 
    -- mod-button1, Set the window to floating mode and move by dragging
    [ ((modMask, button1), (\w -> focus w >> mouseMoveWindow w))
 
    -- mod-button2, Raise the window to the top of the stack
    , ((modMask, button2), (\w -> focus w >> windows W.swapMaster))
 
    -- mod-button3, Set the window to floating mode and resize by dragging
    , ((modMask, button3), (\w -> focus w >> mouseResizeWindow w))
 
    -- you may also bind events to the mouse scroll wheel (button4 and button5)
    ]
 
------------------------------------------------------------------------
-- Layouts:
 
-- You can specify and transform your layouts by modifying these values.
-- If you change layout bindings be sure to use 'mod-shift-space' after
-- restarting (with 'mod-q') to reset your layout state to the new
-- defaults, as xmonad preserves your old layout settings by default.
--
-- The available layouts.  Note that each layout is separated by |||,
-- which denotes layout choice.
--

myLayout = onWorkspaces ["icq","skype"] chatL $ onWorkspace "mail" mailL $ onWorkspaces["4","5"] pdfL $ onWorkspaces ["web","m-n-t"] webL $ usualL

 
  where

     chatL = reflectHoriz mastergrid
     mailL = Circle
     webL = reflectHoriz wtiled
     pdfL = reflectHoriz pdfgrid
     usualL = tiled ||| Mirror tiled ||| Full ||| reflectHoriz tiled  ||| Grid ||| reflectHoriz mastergrid ||| Circle

     -- default tiling algorithm partitions the screen into two panes
     tiled   = Tall nmaster delta ratio
     wtiled   = Tall nmaster delta wratio
 
     -- The default number of windows in the master pane
     nmaster = 1
 
     -- Default proportion of screen occupied by master pane
     ratio   = 1/2
     wratio   = 3/5
 
     -- Percent of screen to increment by when resizing panes
     delta   = 3/100
     
     mastergrid = mastered (1/100) (1/7) $  Grid
     pdfgrid = mastered (1/100) (20/50) $  Grid
    
 
------------------------------------------------------------------------
-- Window rules:
 
-- Execute arbitrary actions and WindowSet manipulations when managing
-- a new window. You can use this to, for example, always float a
-- particular program, or have a client always appear on a particular
-- workspace.
--
-- To find the property name associated with a program, use
-- > xprop | grep WM_CLASS
-- and click on the client you're interested in.
--
-- To match on the WM_NAME, you can use 'title' in the same way that
-- 'className' and 'resource' are used below.
--
myManageHook = composeAll
    [ className =? "MPlayer"        --> doFloat
    , className =? "Gimp"           --> doFloat
    , className =? "Google-chrome"  --> moveTo "web"
    --, className =? "Thunderbird"  --> doF (W.shift "mail")
    , className =? "Thunderbird"  --> moveTo "mail"
    , className =? "Empathy"  --> moveTo "icq"
    , className =? "Skype"  --> moveTo "skype"
    , resource  =? "desktop_window" --> doIgnore
    , resource  =? "kdesktop"       --> doIgnore ]
    
      where moveTo = doF . W.shift
 
-- Whether focus follows the mouse pointer.
myFocusFollowsMouse :: Bool
myFocusFollowsMouse = True
 
 
------------------------------------------------------------------------
-- Status bars and logging
 
-- Perform an arbitrary action on each internal state change or X event.
-- See the 'DynamicLog' extension for examples.
--
-- To emulate dwm's status bar
--
-- > logHook = dynamicLogDzen
--

--myLogHook = return ()

--myLogHook = dynamicLogWithPP $ xmobarPP
--                        { ppOutput = hPutStrLn xmproc
--                        , ppTitle = xmobarColor "green" "" . shorten 50
--                        }

 
------------------------------------------------------------------------
-- Startup hook
 
-- Perform an arbitrary action each time xmonad starts or is restarted
-- with mod-q.  Used by, e.g., XMonad.Layout.PerWorkspace to initialize
-- per-workspace layout choices.
--
-- By default, do nothing.
-- myStartupHook = return ()

-- myStartupHook = spawn "feh --bg-scale ~/.xmonad/background/Hohl.jpg"

--myStartupHook :: X ()
myStartupHook =  setDefaultCursor xC_left_ptr >>  spawn "sh .fehbg" 

--myStartupHook =  setDefaultCursor xC_left_ptr >>  spawn "sh ~/.xmonad/startxmb.sh" 

--myStartupHook =   setDefaultCursor xC_left_ptr
--myStartupHook = spawn "sh .xmonad/xmstartup.sh"
 
------------------------------------------------------------------------
-- Now run xmonad with all the defaults we set up.
 
-- Run xmonad with the settings you specify. No need to modify this.
--
main = do
xmproc <- spawnPipe "/usr/bin/xmobar ~/.xmobarcc"
xmonad $ defaultConfig {
      -- simple stuff
        terminal           = myTerminal,
        focusFollowsMouse  = myFocusFollowsMouse,
        borderWidth        = myBorderWidth,
        modMask            = myModMask,
        numlockMask        = myNumlockMask,
        workspaces         = myWorkspaces,
        normalBorderColor  = myNormalBorderColor,
        focusedBorderColor = myFocusedBorderColor,
 
      -- key bindings
        keys               = myKeys,
        mouseBindings      = myMouseBindings,
 
      -- hooks, layouts
        layoutHook         = avoidStruts myLayout,
        manageHook         = manageDocks <+> myManageHook 
                             <+> manageHook defaultConfig,
        logHook            =  dynamicLogWithPP $ xmobarPP
                        { ppOutput = hPutStrLn xmproc
                        , ppTitle = xmobarColor "green" "" . shorten 50
                        } ,

        startupHook        = myStartupHook 
    }
